# geoimage_heic
Add Latitude and Longitude to HEIC images

Usage: geoimage [input directory] [output directory]

[sample output](https://github.com/Gerardwx/geoimage_heic/blob/main/sample/trailreport-2.jpg)

Arimo-VariableFont_wght.ttf from fonts.google.com (Apache License)
